@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,15 +18,28 @@
 # under the License.
 
 from aliyunsdkcore.request import RoaRequest
+from aliyunsdkcs.endpoint import endpoint_data
+
 class DescribeClustersRequest(RoaRequest):
 
 	def __init__(self):
 		RoaRequest.__init__(self, 'CS', '2015-12-15', 'DescribeClusters')
 		self.set_uri_pattern('/clusters')
 		self.set_method('GET')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_Name(self):
-		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+	def get_clusterType(self):
+		return self.get_query_params().get('clusterType')
+
+	def set_clusterType(self,clusterType):
+		self.add_query_param('clusterType',clusterType)
+
+	def get_name(self):
+		return self.get_query_params().get('name')
+
+	def set_name(self,name):
+		self.add_query_param('name',name)
\ No newline at end of file
