@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,9 +18,22 @@
 # under the License.
 
 from aliyunsdkcore.request import RoaRequest
+from aliyunsdkcs.endpoint import endpoint_data
+
 class DescribeTemplatesRequest(RoaRequest):
 
 	def __init__(self):
 		RoaRequest.__init__(self, 'CS', '2015-12-15', 'DescribeTemplates')
 		self.set_uri_pattern('/templates')
-		self.set_method('GET')
\ No newline at end of file
+		self.set_method('GET')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+
+	def get_template_type(self):
+		return self.get_query_params().get('template_type')
+
+	def set_template_type(self,template_type):
+		self.add_query_param('template_type',template_type)
\ No newline at end of file
